'T list Type
The type of immutable singly-linked lists.
See the List module for further operations related to lists.
Use the constructors [] and :: (infix) to create values of this type, or
the notation [1; 2; 3]. Use the values in the List module to manipulate
values of this type, or pattern match against the values directly.
See also F# Language Guide - Lists.
FSharp.Core