MediumPriority Module
Contains medium-priority overloads for the `task` computation expression builder.
Type extensions
| Type extension |
Description
|
Specifies a unit of task code which draws a result from an F# async value then calls a continuation.
Extended Type:
|
|
Full Usage:
this.MergeSources
Parameters:
Task<^TResult1>
task2 : ^TaskLike2
Returns: Task<^TResult1 * ^TResult2>
Modifiers: inline Type parameters: ^TaskLike2, ^TResult1, ^TResult2, ^Awaiter2 (requires (member GetAwaiter : ^TaskLike2 -> ^Awaiter2) and :> System.Runtime.CompilerServices.ICriticalNotifyCompletion and (member get_IsCompleted : ^Awaiter2 -> Microsoft.FSharp.Core.bool) and (member GetResult : ^Awaiter2 -> ^TResult2)) |
Implementation of the `and!` operation for a task and a task-like value.
Extended Type:
|
Full Usage:
this.MergeSources
Parameters:
^TaskLike1
task2 : Task<^TResult2>
Returns: Task<^TResult1 * ^TResult2>
Modifiers: inline Type parameters: ^TaskLike1, ^TResult1, ^TResult2, ^Awaiter1 (requires (member GetAwaiter : ^TaskLike1 -> ^Awaiter1) and :> System.Runtime.CompilerServices.ICriticalNotifyCompletion and (member get_IsCompleted : ^Awaiter1 -> Microsoft.FSharp.Core.bool) and (member GetResult : ^Awaiter1 -> ^TResult1)) |
Implementation of the `and!` operation for a task-like value and a task.
Extended Type:
|
|
Implementation of the `and!` operation for two asyncs.
Extended Type:
|
|
Implementation of the `and!` operation for a task and an async.
Extended Type:
|
|
Implementation of the `and!` operation for an async and a task.
Extended Type:
|
Full Usage:
this.MergeSources
Parameters:
Task<^TResult1>
task2 : ^TaskLike2
Returns: Task<^TResult1 * ^TResult2>
Modifiers: inline Type parameters: ^TaskLike2, ^TResult1, ^TResult2, ^Awaiter2 (requires (member GetAwaiter : ^TaskLike2 -> ^Awaiter2) and :> System.Runtime.CompilerServices.ICriticalNotifyCompletion and (member get_IsCompleted : ^Awaiter2 -> Microsoft.FSharp.Core.bool) and (member GetResult : ^Awaiter2 -> ^TResult2)) |
Implementation of the `and!` operation for a task and a task-like value.
Extended Type:
|
Full Usage:
this.MergeSources
Parameters:
^TaskLike1
task2 : Task<^TResult2>
Returns: Task<^TResult1 * ^TResult2>
Modifiers: inline Type parameters: ^TaskLike1, ^TResult1, ^TResult2, ^Awaiter1 (requires (member GetAwaiter : ^TaskLike1 -> ^Awaiter1) and :> System.Runtime.CompilerServices.ICriticalNotifyCompletion and (member get_IsCompleted : ^Awaiter1 -> Microsoft.FSharp.Core.bool) and (member GetResult : ^Awaiter1 -> ^TResult1)) |
Implementation of the `and!` operation for a task-like value and a task.
Extended Type:
|
|
Implementation of the `and!` operation for two asyncs.
Extended Type:
|
|
Implementation of the `and!` operation for a task and an async.
Extended Type:
|
|
Implementation of the `and!` operation for an async and a task.
Extended Type:
|
|
Specifies a unit of task code which draws a result from an F# async value.
Extended Type:
|
FSharp.Core