TypeProviderDefinitionLocationAttribute Type
A type provider may provide an instance of this attribute to indicate the definition location for a provided type or member.
Constructors
| Constructor |
Description
|
Full Usage:
TypeProviderDefinitionLocationAttribute()
Returns: TypeProviderDefinitionLocationAttribute
|
FSharp.Core