EqualityConditionalOnAttribute Type
This attribute is used to indicate a generic container type satisfies the F# 'equality' constraint only if a generic argument also satisfies this constraint.
For example, adding this attribute to parameter 'T on a type definition C<'T> means that a type C<X> only supports equality if the type X also supports equality and all other conditions for C<X> to support equality are also met. The type C<'T> can still be used with other type arguments, but a type such as C<(int -> int)> will not support equality because the type (int -> int) is an F# function type and does not support equality. This attribute will be ignored if it is used on the generic parameters of functions or methods.
Constructors
| Constructor |
Description
|
Full Usage:
EqualityConditionalOnAttribute()
Returns: EqualityConditionalOnAttribute
EqualityConditionalOnAttribute
|
Creates an instance of the attribute
|
FSharp.Core