Logo FSharp.Core

OperatorIntrinsics Module

A module of compiler intrinsic functions for efficient implementations of F# integer ranges
 and dynamic invocations of other F# operators

Functions and values

Function or value Description

GetArraySlice source start finish

Full Usage: GetArraySlice source start finish

Parameters:
Returns: 'T array The sub array from the input indices.
Modifiers: inline
Type parameters: 'T

Gets a slice of an array

source : 'T array

The input array.

start : int option

The start index.

finish : int option

The end index.

Returns: 'T array

The sub array from the input indices.

GetArraySlice2D source start1 finish1 start2 finish2

Full Usage: GetArraySlice2D source start1 finish1 start2 finish2

Parameters:
    source : 'T[,] - The source array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.

Returns: 'T[,] The two dimensional sub array from the input indices.
Modifiers: inline
Type parameters: 'T

Gets a region slice of an array

source : 'T[,]

The source array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

Returns: 'T[,]

The two dimensional sub array from the input indices.

GetArraySlice2DFixed1 source index1 start2 finish2

Full Usage: GetArraySlice2DFixed1 source index1 start2 finish2

Parameters:
    source : 'T[,] - The source array.
    index1 : int - The index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.

Returns: 'T array The sub array from the input indices.
Modifiers: inline
Type parameters: 'T

Gets a vector slice of a 2D array. The index of the first dimension is fixed.

source : 'T[,]

The source array.

index1 : int

The index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

Returns: 'T array

The sub array from the input indices.

GetArraySlice2DFixed2 source start1 finish1 index2

Full Usage: GetArraySlice2DFixed2 source start1 finish1 index2

Parameters:
    source : 'T[,] - The source array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    index2 : int - The fixed index of the second dimension.

Returns: 'T array The sub array from the input indices.
Modifiers: inline
Type parameters: 'T

Gets a vector slice of a 2D array. The index of the second dimension is fixed.

source : 'T[,]

The source array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

index2 : int

The fixed index of the second dimension.

Returns: 'T array

The sub array from the input indices.

GetArraySlice3D source start1 finish1 start2 finish2 start3 finish3

Full Usage: GetArraySlice3D source start1 finish1 start2 finish2 start3 finish3

Parameters:
    source : 'T[,,] - The source array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    start3 : int option - The start index of the third dimension.
    finish3 : int option - The end index of the third dimension.

Returns: 'T[,,] The three dimensional sub array from the given indices.
Modifiers: inline
Type parameters: 'T

Gets a slice of an array

source : 'T[,,]

The source array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

start3 : int option

The start index of the third dimension.

finish3 : int option

The end index of the third dimension.

Returns: 'T[,,]

The three dimensional sub array from the given indices.

GetArraySlice3DFixedDouble1 source index1 index2 start3 finish3

Full Usage: GetArraySlice3DFixedDouble1 source index1 index2 start3 finish3

Parameters:
    source : 'T[,,] - The source array.
    index1 : int - The fixed index of the first dimension.
    index2 : int - The fixed index of the second dimension.
    start3 : int option - The start index of the third dimension.
    finish3 : int option - The end index of the third dimension.

Returns: 'T array The one dimensional sub array from the given indices.
Modifiers: inline
Type parameters: 'T

Gets a 1D slice of a 3D array.

source : 'T[,,]

The source array.

index1 : int

The fixed index of the first dimension.

index2 : int

The fixed index of the second dimension.

start3 : int option

The start index of the third dimension.

finish3 : int option

The end index of the third dimension.

Returns: 'T array

The one dimensional sub array from the given indices.

GetArraySlice3DFixedDouble2 source index1 start2 finish2 index3

Full Usage: GetArraySlice3DFixedDouble2 source index1 start2 finish2 index3

Parameters:
    source : 'T[,,] - The source array.
    index1 : int - The fixed index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    index3 : int - The fixed index of the third dimension.

Returns: 'T array The one dimensional sub array from the given indices.
Modifiers: inline
Type parameters: 'T

Gets a 1D slice of a 3D array.

source : 'T[,,]

The source array.

index1 : int

The fixed index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

index3 : int

The fixed index of the third dimension.

Returns: 'T array

The one dimensional sub array from the given indices.

GetArraySlice3DFixedDouble3 source start1 finish1 index2 index3

Full Usage: GetArraySlice3DFixedDouble3 source start1 finish1 index2 index3

Parameters:
    source : 'T[,,] - The source array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    index2 : int - The fixed index of the second dimension.
    index3 : int - The fixed index of the third dimension.

Returns: 'T array The one dimensional sub array from the given indices.
Modifiers: inline
Type parameters: 'T

Gets a 1D slice of a 3D array.

source : 'T[,,]

The source array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

index2 : int

The fixed index of the second dimension.

index3 : int

The fixed index of the third dimension.

Returns: 'T array

The one dimensional sub array from the given indices.

GetArraySlice3DFixedSingle1 source index1 start2 finish2 start3 finish3

Full Usage: GetArraySlice3DFixedSingle1 source index1 start2 finish2 start3 finish3

Parameters:
    source : 'T[,,] - The source array.
    index1 : int - The fixed index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    start3 : int option - The start index of the third dimension.
    finish3 : int option - The end index of the third dimension.

Returns: 'T[,] The two dimensional sub array from the given indices.
Modifiers: inline
Type parameters: 'T

Gets a 2D slice of a 3D array.

source : 'T[,,]

The source array.

index1 : int

The fixed index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

start3 : int option

The start index of the third dimension.

finish3 : int option

The end index of the third dimension.

Returns: 'T[,]

The two dimensional sub array from the given indices.

GetArraySlice3DFixedSingle2 source start1 finish1 index2 start3 finish3

Full Usage: GetArraySlice3DFixedSingle2 source start1 finish1 index2 start3 finish3

Parameters:
    source : 'T[,,] - The source array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    index2 : int - The fixed index of the second dimension.
    start3 : int option - The start index of the third dimension.
    finish3 : int option - The end index of the third dimension.

Returns: 'T[,] The two dimensional sub array from the given indices.
Modifiers: inline
Type parameters: 'T

Gets a 2D slice of a 3D array.

source : 'T[,,]

The source array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

index2 : int

The fixed index of the second dimension.

start3 : int option

The start index of the third dimension.

finish3 : int option

The end index of the third dimension.

Returns: 'T[,]

The two dimensional sub array from the given indices.

GetArraySlice3DFixedSingle3 source start1 finish1 start2 finish2 index3

Full Usage: GetArraySlice3DFixedSingle3 source start1 finish1 start2 finish2 index3

Parameters:
    source : 'T[,,] - The source array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    index3 : int - The fixed index of the third dimension.

Returns: 'T[,] The two dimensional sub array from the given indices.
Modifiers: inline
Type parameters: 'T

Gets a 2D slice of a 3D array.

source : 'T[,,]

The source array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

index3 : int

The fixed index of the third dimension.

Returns: 'T[,]

The two dimensional sub array from the given indices.

GetArraySlice4D source start1 finish1 start2 finish2 start3 finish3 start4 finish4

Full Usage: GetArraySlice4D source start1 finish1 start2 finish2 start3 finish3 start4 finish4

Parameters:
    source : 'T[,,,] - The source array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    start3 : int option - The start index of the third dimension.
    finish3 : int option - The end index of the third dimension.
    start4 : int option - The start index of the fourth dimension.
    finish4 : int option - The end index of the fourth dimension.

Returns: 'T[,,,] The four dimensional sub array from the given indices.
Modifiers: inline
Type parameters: 'T

Gets a slice of an array

source : 'T[,,,]

The source array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

start3 : int option

The start index of the third dimension.

finish3 : int option

The end index of the third dimension.

start4 : int option

The start index of the fourth dimension.

finish4 : int option

The end index of the fourth dimension.

Returns: 'T[,,,]

The four dimensional sub array from the given indices.

GetArraySlice4DFixedDouble1 source index1 index2 start3 finish3 start4 finish4

Full Usage: GetArraySlice4DFixedDouble1 source index1 index2 start3 finish3 start4 finish4

Parameters:
    source : 'T[,,,] - The source array.
    index1 : int - The fixed index of the first dimension.
    index2 : int - The fixed index of the second dimension.
    start3 : int option - The start index of the third dimension.
    finish3 : int option - The end index of the third dimension.
    start4 : int option - The start index of the fourth dimension.
    finish4 : int option - The end index of the fourth dimension.

Returns: 'T[,] The two dimensional sub array from the given indices.
Modifiers: inline
Type parameters: 'T

Gets a 2D slice of a 4D array

source : 'T[,,,]

The source array.

index1 : int

The fixed index of the first dimension.

index2 : int

The fixed index of the second dimension.

start3 : int option

The start index of the third dimension.

finish3 : int option

The end index of the third dimension.

start4 : int option

The start index of the fourth dimension.

finish4 : int option

The end index of the fourth dimension.

Returns: 'T[,]

The two dimensional sub array from the given indices.

GetArraySlice4DFixedDouble2 source index1 start2 finish2 index3 start4 finish4

Full Usage: GetArraySlice4DFixedDouble2 source index1 start2 finish2 index3 start4 finish4

Parameters:
    source : 'T[,,,] - The source array.
    index1 : int - The fixed index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    index3 : int - The fixed index of the third dimension.
    start4 : int option - The start index of the fourth dimension.
    finish4 : int option - The end index of the fourth dimension.

Returns: 'T[,] The two dimensional sub array from the given indices.
Modifiers: inline
Type parameters: 'T

Gets a 2D slice of a 4D array

source : 'T[,,,]

The source array.

index1 : int

The fixed index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

index3 : int

The fixed index of the third dimension.

start4 : int option

The start index of the fourth dimension.

finish4 : int option

The end index of the fourth dimension.

Returns: 'T[,]

The two dimensional sub array from the given indices.

GetArraySlice4DFixedDouble3 source index1 start2 finish2 start3 finish3 index4

Full Usage: GetArraySlice4DFixedDouble3 source index1 start2 finish2 start3 finish3 index4

Parameters:
    source : 'T[,,,] - The source array.
    index1 : int - The fixed index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    start3 : int option - The start index of the third dimension.
    finish3 : int option - The end index of the third dimension.
    index4 : int - The fixed index of the fourth dimension.

Returns: 'T[,] The two dimensional sub array from the given indices.
Modifiers: inline
Type parameters: 'T

Gets a 2D slice of a 4D array

source : 'T[,,,]

The source array.

index1 : int

The fixed index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

start3 : int option

The start index of the third dimension.

finish3 : int option

The end index of the third dimension.

index4 : int

The fixed index of the fourth dimension.

Returns: 'T[,]

The two dimensional sub array from the given indices.

GetArraySlice4DFixedDouble4 source start1 finish1 index2 index3 start4 finish4

Full Usage: GetArraySlice4DFixedDouble4 source start1 finish1 index2 index3 start4 finish4

Parameters:
    source : 'T[,,,] - The source array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    index2 : int - The fixed index of the second dimension.
    index3 : int - The fixed index of the third dimension.
    start4 : int option - The start index of the fourth dimension.
    finish4 : int option - The end index of the fourth dimension.

Returns: 'T[,] The two dimensional sub array from the given indices.
Modifiers: inline
Type parameters: 'T

Gets a 2D slice of a 4D array

source : 'T[,,,]

The source array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

index2 : int

The fixed index of the second dimension.

index3 : int

The fixed index of the third dimension.

start4 : int option

The start index of the fourth dimension.

finish4 : int option

The end index of the fourth dimension.

Returns: 'T[,]

The two dimensional sub array from the given indices.

GetArraySlice4DFixedDouble5 source start1 finish1 index2 start3 finish3 index4

Full Usage: GetArraySlice4DFixedDouble5 source start1 finish1 index2 start3 finish3 index4

Parameters:
    source : 'T[,,,] - The source array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    index2 : int - The fixed index of the second dimension.
    start3 : int option - The start index of the third dimension.
    finish3 : int option - The end index of the third dimension.
    index4 : int - The fixed index of the fourth dimension.

Returns: 'T[,] The two dimensional sub array from the given indices.
Modifiers: inline
Type parameters: 'T

Gets a 2D slice of a 4D array

source : 'T[,,,]

The source array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

index2 : int

The fixed index of the second dimension.

start3 : int option

The start index of the third dimension.

finish3 : int option

The end index of the third dimension.

index4 : int

The fixed index of the fourth dimension.

Returns: 'T[,]

The two dimensional sub array from the given indices.

GetArraySlice4DFixedDouble6 source start1 finish1 start2 finish2 index3 index4

Full Usage: GetArraySlice4DFixedDouble6 source start1 finish1 start2 finish2 index3 index4

Parameters:
    source : 'T[,,,] - The source array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    index3 : int - The fixed index of the third dimension.
    index4 : int - The fixed index of the fourth dimension.

Returns: 'T[,] The two dimensional sub array from the given indices.
Modifiers: inline
Type parameters: 'T

Gets a 2D slice of a 4D array

source : 'T[,,,]

The source array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

index3 : int

The fixed index of the third dimension.

index4 : int

The fixed index of the fourth dimension.

Returns: 'T[,]

The two dimensional sub array from the given indices.

GetArraySlice4DFixedSingle1 source index1 start2 finish2 start3 finish3 start4 finish4

Full Usage: GetArraySlice4DFixedSingle1 source index1 start2 finish2 start3 finish3 start4 finish4

Parameters:
    source : 'T[,,,] - The source array.
    index1 : int - The fixed index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    start3 : int option - The start index of the third dimension.
    finish3 : int option - The end index of the third dimension.
    start4 : int option - The start index of the fourth dimension.
    finish4 : int option - The end index of the fourth dimension.

Returns: 'T[,,] The three dimensional sub array from the given indices.
Modifiers: inline
Type parameters: 'T

Gets a 3D slice of a 4D array

source : 'T[,,,]

The source array.

index1 : int

The fixed index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

start3 : int option

The start index of the third dimension.

finish3 : int option

The end index of the third dimension.

start4 : int option

The start index of the fourth dimension.

finish4 : int option

The end index of the fourth dimension.

Returns: 'T[,,]

The three dimensional sub array from the given indices.

GetArraySlice4DFixedSingle2 source start1 finish1 index2 start3 finish3 start4 finish4

Full Usage: GetArraySlice4DFixedSingle2 source start1 finish1 index2 start3 finish3 start4 finish4

Parameters:
    source : 'T[,,,] - The source array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    index2 : int - The fixed index of the second dimension.
    start3 : int option - The start index of the third dimension.
    finish3 : int option - The end index of the third dimension.
    start4 : int option - The start index of the fourth dimension.
    finish4 : int option - The end index of the fourth dimension.

Returns: 'T[,,] The three dimensional sub array from the given indices.
Modifiers: inline
Type parameters: 'T

Gets a 3D slice of a 4D array

source : 'T[,,,]

The source array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

index2 : int

The fixed index of the second dimension.

start3 : int option

The start index of the third dimension.

finish3 : int option

The end index of the third dimension.

start4 : int option

The start index of the fourth dimension.

finish4 : int option

The end index of the fourth dimension.

Returns: 'T[,,]

The three dimensional sub array from the given indices.

GetArraySlice4DFixedSingle3 source start1 finish1 start2 finish2 index3 start4 finish4

Full Usage: GetArraySlice4DFixedSingle3 source start1 finish1 start2 finish2 index3 start4 finish4

Parameters:
    source : 'T[,,,] - The source array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    index3 : int - The fixed index of the third dimension.
    start4 : int option - The start index of the fourth dimension.
    finish4 : int option - The end index of the fourth dimension.

Returns: 'T[,,] The three dimensional sub array from the given indices.
Modifiers: inline
Type parameters: 'T

Gets a 3D slice of a 4D array

source : 'T[,,,]

The source array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

index3 : int

The fixed index of the third dimension.

start4 : int option

The start index of the fourth dimension.

finish4 : int option

The end index of the fourth dimension.

Returns: 'T[,,]

The three dimensional sub array from the given indices.

GetArraySlice4DFixedSingle4 source start1 finish1 start2 finish2 start3 finish3 index4

Full Usage: GetArraySlice4DFixedSingle4 source start1 finish1 start2 finish2 start3 finish3 index4

Parameters:
    source : 'T[,,,] - The source array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    start3 : int option - The start index of the third dimension.
    finish3 : int option - The end index of the third dimension.
    index4 : int - The fixed index of the fourth dimension.

Returns: 'T[,,] The three dimensional sub array from the given indices.
Modifiers: inline
Type parameters: 'T

Gets a 3D slice of a 4D array

source : 'T[,,,]

The source array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

start3 : int option

The start index of the third dimension.

finish3 : int option

The end index of the third dimension.

index4 : int

The fixed index of the fourth dimension.

Returns: 'T[,,]

The three dimensional sub array from the given indices.

GetArraySlice4DFixedTriple1 source start1 finish1 index2 index3 index4

Full Usage: GetArraySlice4DFixedTriple1 source start1 finish1 index2 index3 index4

Parameters:
    source : 'T[,,,] - The source array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    index2 : int - The fixed index of the second dimension.
    index3 : int - The fixed index of the third dimension.
    index4 : int - The fixed index of the fourth dimension.

Returns: 'T array The one dimensional sub array from the given indices.
Modifiers: inline
Type parameters: 'T

Gets a 1D slice of a 4D array

source : 'T[,,,]

The source array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

index2 : int

The fixed index of the second dimension.

index3 : int

The fixed index of the third dimension.

index4 : int

The fixed index of the fourth dimension.

Returns: 'T array

The one dimensional sub array from the given indices.

GetArraySlice4DFixedTriple2 source index1 start2 finish2 index3 index4

Full Usage: GetArraySlice4DFixedTriple2 source index1 start2 finish2 index3 index4

Parameters:
    source : 'T[,,,] - The source array.
    index1 : int - The fixed index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    index3 : int - The fixed index of the third dimension.
    index4 : int - The fixed index of the fourth dimension.

Returns: 'T array The one dimensional sub array from the given indices.
Modifiers: inline
Type parameters: 'T

Gets a 1D slice of a 4D array

source : 'T[,,,]

The source array.

index1 : int

The fixed index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

index3 : int

The fixed index of the third dimension.

index4 : int

The fixed index of the fourth dimension.

Returns: 'T array

The one dimensional sub array from the given indices.

GetArraySlice4DFixedTriple3 source index1 index2 start3 finish3 index4

Full Usage: GetArraySlice4DFixedTriple3 source index1 index2 start3 finish3 index4

Parameters:
    source : 'T[,,,] - The source array.
    index1 : int - The fixed index of the first dimension.
    index2 : int - The fixed index of the second dimension.
    start3 : int option - The start index of the third dimension.
    finish3 : int option - The end index of the third dimension.
    index4 : int - The fixed index of the fourth dimension.

Returns: 'T array The one dimensional sub array from the given indices.
Modifiers: inline
Type parameters: 'T

Gets a 1D slice of a 4D array

source : 'T[,,,]

The source array.

index1 : int

The fixed index of the first dimension.

index2 : int

The fixed index of the second dimension.

start3 : int option

The start index of the third dimension.

finish3 : int option

The end index of the third dimension.

index4 : int

The fixed index of the fourth dimension.

Returns: 'T array

The one dimensional sub array from the given indices.

GetArraySlice4DFixedTriple4 source index1 index2 index3 start4 finish4

Full Usage: GetArraySlice4DFixedTriple4 source index1 index2 index3 start4 finish4

Parameters:
    source : 'T[,,,] - The source array.
    index1 : int - The fixed index of the first dimension.
    index2 : int - The fixed index of the second dimension.
    index3 : int - The fixed index of the third dimension.
    start4 : int option - The start index of the fourth dimension.
    finish4 : int option - The end index of the fourth dimension.

Returns: 'T array The one dimensional sub array from the given indices.
Modifiers: inline
Type parameters: 'T

Gets a 1D slice of a 4D array

source : 'T[,,,]

The source array.

index1 : int

The fixed index of the first dimension.

index2 : int

The fixed index of the second dimension.

index3 : int

The fixed index of the third dimension.

start4 : int option

The start index of the fourth dimension.

finish4 : int option

The end index of the fourth dimension.

Returns: 'T array

The one dimensional sub array from the given indices.

GetStringSlice source start finish

Full Usage: GetStringSlice source start finish

Parameters:
    source : string - The source string.
    start : int option - The index of the first character of the slice.
    finish : int option - The index of the last character of the slice.

Returns: string The substring from the given indices.
Modifiers: inline

Gets a slice from a string

source : string

The source string.

start : int option

The index of the first character of the slice.

finish : int option

The index of the last character of the slice.

Returns: string

The substring from the given indices.

SetArraySlice target start finish source

Full Usage: SetArraySlice target start finish source

Parameters:
    target : 'T array - The target array.
    start : int option - The start index.
    finish : int option - The end index.
    source : 'T array - The source array.

Modifiers: inline
Type parameters: 'T

Sets a slice of an array

target : 'T array

The target array.

start : int option

The start index.

finish : int option

The end index.

source : 'T array

The source array.

SetArraySlice2D target start1 finish1 start2 finish2 source

Full Usage: SetArraySlice2D target start1 finish1 start2 finish2 source

Parameters:
    target : 'T[,] - The target array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    source : 'T[,] - The source array.

Modifiers: inline
Type parameters: 'T

Sets a region slice of an array

target : 'T[,]

The target array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

source : 'T[,]

The source array.

SetArraySlice2DFixed1 target index1 start2 finish2 source

Full Usage: SetArraySlice2DFixed1 target index1 start2 finish2 source

Parameters:
    target : 'T[,] - The target array.
    index1 : int - The index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    source : 'T array - The source array.

Modifiers: inline
Type parameters: 'T

Sets a vector slice of a 2D array. The index of the first dimension is fixed.

target : 'T[,]

The target array.

index1 : int

The index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

source : 'T array

The source array.

SetArraySlice2DFixed2 target start1 finish1 index2 source

Full Usage: SetArraySlice2DFixed2 target start1 finish1 index2 source

Parameters:
    target : 'T[,] - The target array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    index2 : int - The index of the second dimension.
    source : 'T array - The source array.

Modifiers: inline
Type parameters: 'T

Sets a vector slice of a 2D array. The index of the second dimension is fixed.

target : 'T[,]

The target array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

index2 : int

The index of the second dimension.

source : 'T array

The source array.

SetArraySlice3D target start1 finish1 start2 finish2 start3 finish3 source

Full Usage: SetArraySlice3D target start1 finish1 start2 finish2 start3 finish3 source

Parameters:
    target : 'T[,,] - The target array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    start3 : int option - The start index of the third dimension.
    finish3 : int option - The end index of the third dimension.
    source : 'T[,,] - The source array.

Modifiers: inline
Type parameters: 'T

Sets a slice of an array

target : 'T[,,]

The target array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

start3 : int option

The start index of the third dimension.

finish3 : int option

The end index of the third dimension.

source : 'T[,,]

The source array.

SetArraySlice3DFixedDouble1 target index1 index2 start3 finish3 source

Full Usage: SetArraySlice3DFixedDouble1 target index1 index2 start3 finish3 source

Parameters:
    target : 'T[,,] - The target array.
    index1 : int - The fixed index of the first dimension.
    index2 : int - The fixed index of the second dimension.
    start3 : int option - The start index of the third dimension.
    finish3 : int option - The end index of the third dimension.
    source : 'T array - The source array.

Modifiers: inline
Type parameters: 'T

Sets a 1D slice of a 3D array.

target : 'T[,,]

The target array.

index1 : int

The fixed index of the first dimension.

index2 : int

The fixed index of the second dimension.

start3 : int option

The start index of the third dimension.

finish3 : int option

The end index of the third dimension.

source : 'T array

The source array.

SetArraySlice3DFixedDouble2 target index1 start2 finish2 index3 source

Full Usage: SetArraySlice3DFixedDouble2 target index1 start2 finish2 index3 source

Parameters:
    target : 'T[,,] - The target array.
    index1 : int - The fixed index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    index3 : int - The fixed index of the third dimension.
    source : 'T array - The source array.

Modifiers: inline
Type parameters: 'T

Sets a 1D slice of a 3D array.

target : 'T[,,]

The target array.

index1 : int

The fixed index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

index3 : int

The fixed index of the third dimension.

source : 'T array

The source array.

SetArraySlice3DFixedDouble3 target start1 finish1 index2 index3 source

Full Usage: SetArraySlice3DFixedDouble3 target start1 finish1 index2 index3 source

Parameters:
    target : 'T[,,] - The target array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    index2 : int - The fixed index of the second dimension.
    index3 : int - The fixed index of the third dimension.
    source : 'T array - The source array.

Modifiers: inline
Type parameters: 'T

Sets a 1D slice of a 3D array.

target : 'T[,,]

The target array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

index2 : int

The fixed index of the second dimension.

index3 : int

The fixed index of the third dimension.

source : 'T array

The source array.

SetArraySlice3DFixedSingle1 target index1 start2 finish2 start3 finish3 source

Full Usage: SetArraySlice3DFixedSingle1 target index1 start2 finish2 start3 finish3 source

Parameters:
    target : 'T[,,] - The target array.
    index1 : int - The fixed index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    start3 : int option - The start index of the third dimension.
    finish3 : int option - The end index of the third dimension.
    source : 'T[,] - The source array.

Modifiers: inline
Type parameters: 'T

Sets a 2D slice of a 3D array

target : 'T[,,]

The target array.

index1 : int

The fixed index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

start3 : int option

The start index of the third dimension.

finish3 : int option

The end index of the third dimension.

source : 'T[,]

The source array.

SetArraySlice3DFixedSingle2 target start1 finish1 index2 start3 finish3 source

Full Usage: SetArraySlice3DFixedSingle2 target start1 finish1 index2 start3 finish3 source

Parameters:
    target : 'T[,,] - The target array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    index2 : int - The fixed index of the second dimension.
    start3 : int option - The start index of the third dimension.
    finish3 : int option - The end index of the third dimension.
    source : 'T[,] - The source array.

Modifiers: inline
Type parameters: 'T

Sets a 2D slice of a 3D array

target : 'T[,,]

The target array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

index2 : int

The fixed index of the second dimension.

start3 : int option

The start index of the third dimension.

finish3 : int option

The end index of the third dimension.

source : 'T[,]

The source array.

SetArraySlice3DFixedSingle3 target start1 finish1 start2 finish2 index3 source

Full Usage: SetArraySlice3DFixedSingle3 target start1 finish1 start2 finish2 index3 source

Parameters:
    target : 'T[,,] - The target array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    index3 : int - The fixed index of the third dimension.
    source : 'T[,] - The source array.

Modifiers: inline
Type parameters: 'T

Sets a 2D slice of a 3D array

target : 'T[,,]

The target array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

index3 : int

The fixed index of the third dimension.

source : 'T[,]

The source array.

SetArraySlice4D target start1 finish1 start2 finish2 start3 finish3 start4 finish4 source

Full Usage: SetArraySlice4D target start1 finish1 start2 finish2 start3 finish3 start4 finish4 source

Parameters:
    target : 'T[,,,] - The target array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    start3 : int option - The start index of the third dimension.
    finish3 : int option - The end index of the third dimension.
    start4 : int option - The start index of the fourth dimension.
    finish4 : int option - The end index of the fourth dimension.
    source : 'T[,,,] - The source array.

Modifiers: inline
Type parameters: 'T

Sets a slice of an array

target : 'T[,,,]

The target array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

start3 : int option

The start index of the third dimension.

finish3 : int option

The end index of the third dimension.

start4 : int option

The start index of the fourth dimension.

finish4 : int option

The end index of the fourth dimension.

source : 'T[,,,]

The source array.

SetArraySlice4DFixedDouble1 target index1 index2 start3 finish3 start4 finish4 source

Full Usage: SetArraySlice4DFixedDouble1 target index1 index2 start3 finish3 start4 finish4 source

Parameters:
    target : 'T[,,,] - The target array.
    index1 : int - The fixed index of the first dimension.
    index2 : int - The fixed index of the second dimension.
    start3 : int option - The start index of the third dimension.
    finish3 : int option - The end index of the third dimension.
    start4 : int option - The start index of the fourth dimension.
    finish4 : int option - The end index of the fourth dimension.
    source : 'T[,] - The source array.

Modifiers: inline
Type parameters: 'T

Sets a 2D slice of a 4D array

target : 'T[,,,]

The target array.

index1 : int

The fixed index of the first dimension.

index2 : int

The fixed index of the second dimension.

start3 : int option

The start index of the third dimension.

finish3 : int option

The end index of the third dimension.

start4 : int option

The start index of the fourth dimension.

finish4 : int option

The end index of the fourth dimension.

source : 'T[,]

The source array.

SetArraySlice4DFixedDouble2 target index1 start2 finish2 index3 start4 finish4 source

Full Usage: SetArraySlice4DFixedDouble2 target index1 start2 finish2 index3 start4 finish4 source

Parameters:
    target : 'T[,,,] - The target array.
    index1 : int - The fixed index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    index3 : int - The fixed index of the third dimension.
    start4 : int option - The start index of the fourth dimension.
    finish4 : int option - The end index of the fourth dimension.
    source : 'T[,] - The source array.

Modifiers: inline
Type parameters: 'T

Sets a 2D slice of a 4D array

target : 'T[,,,]

The target array.

index1 : int

The fixed index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

index3 : int

The fixed index of the third dimension.

start4 : int option

The start index of the fourth dimension.

finish4 : int option

The end index of the fourth dimension.

source : 'T[,]

The source array.

SetArraySlice4DFixedDouble3 target index1 start2 finish2 start3 finish3 index4 source

Full Usage: SetArraySlice4DFixedDouble3 target index1 start2 finish2 start3 finish3 index4 source

Parameters:
    target : 'T[,,,] - The target array.
    index1 : int - The fixed index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    start3 : int option - The start index of the third dimension.
    finish3 : int option - The end index of the third dimension.
    index4 : int - The fixed index of the fourth dimension.
    source : 'T[,] - The source array.

Modifiers: inline
Type parameters: 'T

Sets a 2D slice of a 4D array

target : 'T[,,,]

The target array.

index1 : int

The fixed index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

start3 : int option

The start index of the third dimension.

finish3 : int option

The end index of the third dimension.

index4 : int

The fixed index of the fourth dimension.

source : 'T[,]

The source array.

SetArraySlice4DFixedDouble4 target start1 finish1 index2 index3 start4 finish4 source

Full Usage: SetArraySlice4DFixedDouble4 target start1 finish1 index2 index3 start4 finish4 source

Parameters:
    target : 'T[,,,] - The target array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    index2 : int - The fixed index of the second dimension.
    index3 : int - The fixed index of the third dimension.
    start4 : int option - The start index of the fourth dimension.
    finish4 : int option - The end index of the fourth dimension.
    source : 'T[,] - The source array.

Modifiers: inline
Type parameters: 'T

Sets a 2D slice of a 4D array

target : 'T[,,,]

The target array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

index2 : int

The fixed index of the second dimension.

index3 : int

The fixed index of the third dimension.

start4 : int option

The start index of the fourth dimension.

finish4 : int option

The end index of the fourth dimension.

source : 'T[,]

The source array.

SetArraySlice4DFixedDouble5 target start1 finish1 index2 start3 finish3 index4 source

Full Usage: SetArraySlice4DFixedDouble5 target start1 finish1 index2 start3 finish3 index4 source

Parameters:
    target : 'T[,,,] - The target array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    index2 : int - The fixed index of the second dimension.
    start3 : int option - The start index of the third dimension.
    finish3 : int option - The end index of the third dimension.
    index4 : int - The fixed index of the fourth dimension.
    source : 'T[,] - The source array.

Modifiers: inline
Type parameters: 'T

Sets a 2D slice of a 4D array

target : 'T[,,,]

The target array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

index2 : int

The fixed index of the second dimension.

start3 : int option

The start index of the third dimension.

finish3 : int option

The end index of the third dimension.

index4 : int

The fixed index of the fourth dimension.

source : 'T[,]

The source array.

SetArraySlice4DFixedDouble6 target start1 finish1 start2 finish2 index3 index4 source

Full Usage: SetArraySlice4DFixedDouble6 target start1 finish1 start2 finish2 index3 index4 source

Parameters:
    target : 'T[,,,] - The target array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    index3 : int - The fixed index of the third dimension.
    index4 : int - The fixed index of the fourth dimension.
    source : 'T[,] - The source array.

Modifiers: inline
Type parameters: 'T

Sets a 2D slice of a 4D array

target : 'T[,,,]

The target array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

index3 : int

The fixed index of the third dimension.

index4 : int

The fixed index of the fourth dimension.

source : 'T[,]

The source array.

SetArraySlice4DFixedSingle1 target index1 start2 finish2 start3 finish3 start4 finish4 source

Full Usage: SetArraySlice4DFixedSingle1 target index1 start2 finish2 start3 finish3 start4 finish4 source

Parameters:
    target : 'T[,,,] - The target array.
    index1 : int - The fixed index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    start3 : int option - The start index of the third dimension.
    finish3 : int option - The end index of the third dimension.
    start4 : int option - The start index of the fourth dimension.
    finish4 : int option - The end index of the fourth dimension.
    source : 'T[,,] - The source array.

Modifiers: inline
Type parameters: 'T

Sets a 3D slice of a 4D array

target : 'T[,,,]

The target array.

index1 : int

The fixed index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

start3 : int option

The start index of the third dimension.

finish3 : int option

The end index of the third dimension.

start4 : int option

The start index of the fourth dimension.

finish4 : int option

The end index of the fourth dimension.

source : 'T[,,]

The source array.

SetArraySlice4DFixedSingle2 target start1 finish1 index2 start3 finish3 start4 finish4 source

Full Usage: SetArraySlice4DFixedSingle2 target start1 finish1 index2 start3 finish3 start4 finish4 source

Parameters:
    target : 'T[,,,] - The target array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    index2 : int - The fixed index of the second dimension.
    start3 : int option - The start index of the third dimension.
    finish3 : int option - The end index of the third dimension.
    start4 : int option - The start index of the fourth dimension.
    finish4 : int option - The end index of the fourth dimension.
    source : 'T[,,] - The source array.

Modifiers: inline
Type parameters: 'T

Sets a 3D slice of a 4D array

target : 'T[,,,]

The target array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

index2 : int

The fixed index of the second dimension.

start3 : int option

The start index of the third dimension.

finish3 : int option

The end index of the third dimension.

start4 : int option

The start index of the fourth dimension.

finish4 : int option

The end index of the fourth dimension.

source : 'T[,,]

The source array.

SetArraySlice4DFixedSingle3 target start1 finish1 start2 finish2 index3 start4 finish4 source

Full Usage: SetArraySlice4DFixedSingle3 target start1 finish1 start2 finish2 index3 start4 finish4 source

Parameters:
    target : 'T[,,,] - The target array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    index3 : int - The fixed index of the third dimension.
    start4 : int option - The start index of the fourth dimension.
    finish4 : int option - The end index of the fourth dimension.
    source : 'T[,,] - The source array.

Modifiers: inline
Type parameters: 'T

Sets a 3D slice of a 4D array

target : 'T[,,,]

The target array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

index3 : int

The fixed index of the third dimension.

start4 : int option

The start index of the fourth dimension.

finish4 : int option

The end index of the fourth dimension.

source : 'T[,,]

The source array.

SetArraySlice4DFixedSingle4 target start1 finish1 start2 finish2 start3 finish3 index4 source

Full Usage: SetArraySlice4DFixedSingle4 target start1 finish1 start2 finish2 start3 finish3 index4 source

Parameters:
    target : 'T[,,,] - The target array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    start3 : int option - The start index of the third dimension.
    finish3 : int option - The end index of the third dimension.
    index4 : int - The fixed index of the fourth dimension.
    source : 'T[,,] - The source array.

Modifiers: inline
Type parameters: 'T

Sets a 3D slice of a 4D array

target : 'T[,,,]

The target array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

start3 : int option

The start index of the third dimension.

finish3 : int option

The end index of the third dimension.

index4 : int

The fixed index of the fourth dimension.

source : 'T[,,]

The source array.

SetArraySlice4DFixedTriple1 target start1 finish1 index2 index3 index4 source

Full Usage: SetArraySlice4DFixedTriple1 target start1 finish1 index2 index3 index4 source

Parameters:
    target : 'T[,,,] - The target array.
    start1 : int option - The start index of the first dimension.
    finish1 : int option - The end index of the first dimension.
    index2 : int - The fixed index of the second dimension.
    index3 : int - The fixed index of the third dimension.
    index4 : int - The fixed index of the fourth dimension.
    source : 'T array - The source array.

Modifiers: inline
Type parameters: 'T

Sets a 1D slice of a 4D array

target : 'T[,,,]

The target array.

start1 : int option

The start index of the first dimension.

finish1 : int option

The end index of the first dimension.

index2 : int

The fixed index of the second dimension.

index3 : int

The fixed index of the third dimension.

index4 : int

The fixed index of the fourth dimension.

source : 'T array

The source array.

SetArraySlice4DFixedTriple2 target index1 start2 finish2 index3 index4 source

Full Usage: SetArraySlice4DFixedTriple2 target index1 start2 finish2 index3 index4 source

Parameters:
    target : 'T[,,,] - The target array.
    index1 : int - The fixed index of the first dimension.
    start2 : int option - The start index of the second dimension.
    finish2 : int option - The end index of the second dimension.
    index3 : int - The fixed index of the third dimension.
    index4 : int - The fixed index of the fourth dimension.
    source : 'T array - The source array.

Modifiers: inline
Type parameters: 'T

Sets a 1D slice of a 4D array

target : 'T[,,,]

The target array.

index1 : int

The fixed index of the first dimension.

start2 : int option

The start index of the second dimension.

finish2 : int option

The end index of the second dimension.

index3 : int

The fixed index of the third dimension.

index4 : int

The fixed index of the fourth dimension.

source : 'T array

The source array.

SetArraySlice4DFixedTriple3 target index1 index2 start3 finish3 index4 source

Full Usage: SetArraySlice4DFixedTriple3 target index1 index2 start3 finish3 index4 source

Parameters:
    target : 'T[,,,] - The target array.
    index1 : int - The fixed index of the first dimension.
    index2 : int - The fixed index of the second dimension.
    start3 : int option - The start index of the third dimension.
    finish3 : int option - The end index of the third dimension.
    index4 : int - The fixed index of the fourth dimension.
    source : 'T array - The source array.

Modifiers: inline
Type parameters: 'T

Sets a 1D slice of a 4D array

target : 'T[,,,]

The target array.

index1 : int

The fixed index of the first dimension.

index2 : int

The fixed index of the second dimension.

start3 : int option

The start index of the third dimension.

finish3 : int option

The end index of the third dimension.

index4 : int

The fixed index of the fourth dimension.

source : 'T array

The source array.

SetArraySlice4DFixedTriple4 target index1 index2 index3 start4 finish4 source

Full Usage: SetArraySlice4DFixedTriple4 target index1 index2 index3 start4 finish4 source

Parameters:
    target : 'T[,,,] - The target array.
    index1 : int - The fixed index of the first dimension.
    index2 : int - The fixed index of the second dimension.
    index3 : int - The fixed index of the third dimension.
    start4 : int option - The start index of the fourth dimension.
    finish4 : int option - The end index of the fourth dimension.
    source : 'T array - The source array.

Modifiers: inline
Type parameters: 'T

Sets a 1D slice of a 4D array

target : 'T[,,,]

The target array.

index1 : int

The fixed index of the first dimension.

index2 : int

The fixed index of the second dimension.

index3 : int

The fixed index of the third dimension.

start4 : int option

The start index of the fourth dimension.

finish4 : int option

The end index of the fourth dimension.

source : 'T array

The source array.

Type something to start searching.