FSharpFunc<'T1, 'T2, 'T3, 'T4, 'T5, 'U> Type
The CLI type used to represent F# function values that accept five curried arguments without intervening execution. This type should not typically used directly from either F# code or from other CLI languages.
Constructors
| Constructor |
Description
|
|
Construct an optimized function value that can accept five curried arguments without intervening execution.
|
Instance members
| Instance member |
Description
|
Full Usage:
this.Invoke
Parameters:
'T1
-
The first arg.
arg2 : 'T2
-
The second arg.
arg3 : 'T3
-
The third arg.
arg4 : 'T4
-
The fourth arg.
arg5 : 'T5
-
The fifth arg.
Returns: 'U
The function result.
Modifiers: abstract |
Invoke an F# first class function value that accepts five curried arguments without intervening execution
|
Static members
| Static member |
Description
|
Full Usage:
FSharpFunc.Adapt(func)
Parameters:
'T1 -> 'T2 -> 'T3 -> 'T4 -> 'T5 -> 'U
-
The input function.
Returns: FSharpFunc<'T1, 'T2, 'T3, 'T4, 'T5, 'U>
The optimized function.
|
Adapt an F# first class function value to be an optimized function value that can accept five curried arguments without intervening execution.
|
Inherited members
Inherited from
FSharpFunc<'T1, ('T2 -> 'T3 -> 'T4 -> 'T5 -> 'U)>
Instance members
| Instance member |
Description
|
Full Usage:
this.Invoke
Parameters:
'T
-
Returns: 'U
'U
Modifiers: abstract |
Invoke an F# first class function value with one argument
|
Static members
| Static member |
Description
|
Full Usage:
FSharpFunc.FromConverter(converter)
Parameters:
Converter<'T, 'U>
-
The input System.Converter.
Returns: 'T -> 'U
An F# function of the same type.
|
|
Full Usage:
FSharpFunc.InvokeFast(func, arg1, arg2)
Parameters:
FSharpFunc<'T, ('U -> 'V)>
-
The input function.
arg1 : 'T
-
The first arg.
arg2 : 'U
-
The second arg.
Returns: 'V
The function result.
|
Invoke an F# first class function value with two curried arguments. In some cases this will result in a more efficient application than applying the arguments successively.
|
Full Usage:
FSharpFunc.InvokeFast(func, arg1, arg2, arg3)
Parameters:
FSharpFunc<'T, ('U -> 'V -> 'W)>
-
The input function.
arg1 : 'T
-
The first arg.
arg2 : 'U
-
The second arg.
arg3 : 'V
-
The third arg.
Returns: 'W
The function result.
|
Invoke an F# first class function value with three curried arguments. In some cases this will result in a more efficient application than applying the arguments successively.
|
Full Usage:
FSharpFunc.InvokeFast(func, arg1, arg2, arg3, arg4)
Parameters:
FSharpFunc<'T, ('U -> 'V -> 'W -> 'X)>
-
The input function.
arg1 : 'T
-
The first arg.
arg2 : 'U
-
The second arg.
arg3 : 'V
-
The third arg.
arg4 : 'W
-
The fourth arg.
Returns: 'X
The function result.
Type parameters: 'X |
Invoke an F# first class function value with four curried arguments. In some cases this will result in a more efficient application than applying the arguments successively.
|
Full Usage:
FSharpFunc.InvokeFast(func, arg1, arg2, arg3, arg4, arg5)
Parameters:
FSharpFunc<'T, ('U -> 'V -> 'W -> 'X -> 'Y)>
-
The input function.
arg1 : 'T
-
The first arg.
arg2 : 'U
-
The second arg.
arg3 : 'V
-
The third arg.
arg4 : 'W
-
The fourth arg.
arg5 : 'X
-
The fifth arg.
Returns: 'Y
The function result.
Type parameters: 'X, 'Y |
Invoke an F# first class function value with five curried arguments. In some cases this will result in a more efficient application than applying the arguments successively.
|
Full Usage:
FSharpFunc.ToConverter(func)
Parameters:
'T -> 'U
-
The input function.
Returns: Converter<'T, 'U>
System.Converter<'T,'U>
|
|
Full Usage:
FSharpFunc.op_Implicit converter
Parameters:
Converter<'T, 'U>
-
The input System.Converter.
Returns: 'T -> 'U
An F# function of the same type.
|
|
Full Usage:
FSharpFunc.op_Implicit func
Parameters:
'T -> 'U
-
The input function.
Returns: Converter<'T, 'U>
A System.Converter of the function type.
|
FSharp.Core