Nullable Module
Functions for converting nullable values
Functions and values
| Function or value |
Description
|
|
Converts the argument to byte. This is a direct conversion for all primitive numeric types. The operation requires an appropriate static conversion method on the input type.
Example
namespace System
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
Multiple items
type Nullable = static member Compare<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> int static member Equals<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> bool static member GetUnderlyingType: nullableType: Type -> Type static member GetValueRefOrDefaultRef<'T (requires default constructor and value type and 'T :> ValueType)> : nullable: inref<Nullable<'T>> -> inref<'T> <summary>Supports a value type that can be assigned <see langword="null" />. This class cannot be inherited.</summary> -------------------- type Nullable<'T (requires default constructor and value type and 'T :> ValueType)> = new: value: 'T -> unit member Equals: other: obj -> bool member GetHashCode: unit -> int member GetValueOrDefault: unit -> 'T + 1 overload member ToString: unit -> string static member op_Explicit: value: Nullable<'T> -> 'T static member op_Implicit: value: 'T -> Nullable<'T> member HasValue: bool member Value: 'T <summary>Represents a value type that can be assigned <see langword="null" />.</summary> <typeparam name="T">The underlying value type of the <see cref="T:System.Nullable`1" /> generic type.</typeparam> -------------------- Nullable () Nullable(value: 'T) : Nullable<'T> Multiple items
val int: value: 'T -> int (requires member op_Explicit) -------------------- type int = int32 -------------------- type int<'Measure> = int |
|
Converts the argument to character. Numeric inputs are converted according to the UTF-16 encoding for characters. The operation requires an appropriate static conversion method on the input type.
Example
namespace System
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
Multiple items
type Nullable = static member Compare<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> int static member Equals<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> bool static member GetUnderlyingType: nullableType: Type -> Type static member GetValueRefOrDefaultRef<'T (requires default constructor and value type and 'T :> ValueType)> : nullable: inref<Nullable<'T>> -> inref<'T> <summary>Supports a value type that can be assigned <see langword="null" />. This class cannot be inherited.</summary> -------------------- type Nullable<'T (requires default constructor and value type and 'T :> ValueType)> = new: value: 'T -> unit member Equals: other: obj -> bool member GetHashCode: unit -> int member GetValueOrDefault: unit -> 'T + 1 overload member ToString: unit -> string static member op_Explicit: value: Nullable<'T> -> 'T static member op_Implicit: value: 'T -> Nullable<'T> member HasValue: bool member Value: 'T <summary>Represents a value type that can be assigned <see langword="null" />.</summary> <typeparam name="T">The underlying value type of the <see cref="T:System.Nullable`1" /> generic type.</typeparam> -------------------- Nullable () Nullable(value: 'T) : Nullable<'T> Multiple items
val int: value: 'T -> int (requires member op_Explicit) -------------------- type int = int32 -------------------- type int<'Measure> = int |
Full Usage:
Nullable.decimal value
Parameters:
Nullable<^T>
-
The input value.
Returns: Nullable<decimal>
The converted decimal.
Modifiers: inline Type parameters: ^T (requires (static member op_Explicit : ^T -> Microsoft.FSharp.Core.decimal) and (new : unit -> ^T) and struct and :> System.ValueType) |
Converts the argument to System.Decimal using a direct conversion for all primitive numeric types. The operation requires an appropriate static conversion method on the input type.
Example
namespace System
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
Multiple items
type Nullable = static member Compare<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> int static member Equals<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> bool static member GetUnderlyingType: nullableType: Type -> Type static member GetValueRefOrDefaultRef<'T (requires default constructor and value type and 'T :> ValueType)> : nullable: inref<Nullable<'T>> -> inref<'T> <summary>Supports a value type that can be assigned <see langword="null" />. This class cannot be inherited.</summary> -------------------- type Nullable<'T (requires default constructor and value type and 'T :> ValueType)> = new: value: 'T -> unit member Equals: other: obj -> bool member GetHashCode: unit -> int member GetValueOrDefault: unit -> 'T + 1 overload member ToString: unit -> string static member op_Explicit: value: Nullable<'T> -> 'T static member op_Implicit: value: 'T -> Nullable<'T> member HasValue: bool member Value: 'T <summary>Represents a value type that can be assigned <see langword="null" />.</summary> <typeparam name="T">The underlying value type of the <see cref="T:System.Nullable`1" /> generic type.</typeparam> -------------------- Nullable () Nullable(value: 'T) : Nullable<'T> Multiple items
val int: value: 'T -> int (requires member op_Explicit) -------------------- type int = int32 -------------------- type int<'Measure> = int |
Full Usage:
Nullable.double value
Parameters:
Nullable<^T>
-
The input value.
Returns: Nullable<double>
The converted float
Modifiers: inline Type parameters: ^T (requires (static member op_Explicit : ^T -> Microsoft.FSharp.Core.double) and (new : unit -> ^T) and struct and :> System.ValueType) |
Converts the argument to 64-bit float. This is a direct conversion for all primitive numeric types. The operation requires an appropriate static conversion method on the input type.
Example
namespace System
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
Multiple items
type Nullable = static member Compare<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> int static member Equals<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> bool static member GetUnderlyingType: nullableType: Type -> Type static member GetValueRefOrDefaultRef<'T (requires default constructor and value type and 'T :> ValueType)> : nullable: inref<Nullable<'T>> -> inref<'T> <summary>Supports a value type that can be assigned <see langword="null" />. This class cannot be inherited.</summary> -------------------- type Nullable<'T (requires default constructor and value type and 'T :> ValueType)> = new: value: 'T -> unit member Equals: other: obj -> bool member GetHashCode: unit -> int member GetValueOrDefault: unit -> 'T + 1 overload member ToString: unit -> string static member op_Explicit: value: Nullable<'T> -> 'T static member op_Implicit: value: 'T -> Nullable<'T> member HasValue: bool member Value: 'T <summary>Represents a value type that can be assigned <see langword="null" />.</summary> <typeparam name="T">The underlying value type of the <see cref="T:System.Nullable`1" /> generic type.</typeparam> -------------------- Nullable () Nullable(value: 'T) : Nullable<'T> Multiple items
val int: value: 'T -> int (requires member op_Explicit) -------------------- type int = int32 -------------------- type int<'Measure> = int |
|
Converts the argument to a particular enum type.
Example
namespace System
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
Multiple items
type Nullable = static member Compare<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> int static member Equals<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> bool static member GetUnderlyingType: nullableType: Type -> Type static member GetValueRefOrDefaultRef<'T (requires default constructor and value type and 'T :> ValueType)> : nullable: inref<Nullable<'T>> -> inref<'T> <summary>Supports a value type that can be assigned <see langword="null" />. This class cannot be inherited.</summary> -------------------- type Nullable<'T (requires default constructor and value type and 'T :> ValueType)> = new: value: 'T -> unit member Equals: other: obj -> bool member GetHashCode: unit -> int member GetValueOrDefault: unit -> 'T + 1 overload member ToString: unit -> string static member op_Explicit: value: Nullable<'T> -> 'T static member op_Implicit: value: 'T -> Nullable<'T> member HasValue: bool member Value: 'T <summary>Represents a value type that can be assigned <see langword="null" />.</summary> <typeparam name="T">The underlying value type of the <see cref="T:System.Nullable`1" /> generic type.</typeparam> -------------------- Nullable () Nullable(value: 'T) : Nullable<'T>
type DayOfWeek =
| Sunday = 0
| Monday = 1
| Tuesday = 2
| Wednesday = 3
| Thursday = 4
| Friday = 5
| Saturday = 6
<summary>Specifies the day of the week.</summary> Multiple items
val int: value: 'T -> int (requires member op_Explicit) -------------------- type int = int32 -------------------- type int<'Measure> = int |
Full Usage:
Nullable.float value
Parameters:
Nullable<^T>
-
The input value.
Returns: Nullable<float>
The converted float
Modifiers: inline Type parameters: ^T (requires (static member op_Explicit : ^T -> Microsoft.FSharp.Core.float) and (new : unit -> ^T) and struct and :> System.ValueType) |
Converts the argument to 64-bit float. This is a direct conversion for all primitive numeric types. The operation requires an appropriate static conversion method on the input type.
Example
namespace System
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
Multiple items
type Nullable = static member Compare<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> int static member Equals<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> bool static member GetUnderlyingType: nullableType: Type -> Type static member GetValueRefOrDefaultRef<'T (requires default constructor and value type and 'T :> ValueType)> : nullable: inref<Nullable<'T>> -> inref<'T> <summary>Supports a value type that can be assigned <see langword="null" />. This class cannot be inherited.</summary> -------------------- type Nullable<'T (requires default constructor and value type and 'T :> ValueType)> = new: value: 'T -> unit member Equals: other: obj -> bool member GetHashCode: unit -> int member GetValueOrDefault: unit -> 'T + 1 overload member ToString: unit -> string static member op_Explicit: value: Nullable<'T> -> 'T static member op_Implicit: value: 'T -> Nullable<'T> member HasValue: bool member Value: 'T <summary>Represents a value type that can be assigned <see langword="null" />.</summary> <typeparam name="T">The underlying value type of the <see cref="T:System.Nullable`1" /> generic type.</typeparam> -------------------- Nullable () Nullable(value: 'T) : Nullable<'T> Multiple items
val int: value: 'T -> int (requires member op_Explicit) -------------------- type int = int32 -------------------- type int<'Measure> = int |
Full Usage:
Nullable.float32 value
Parameters:
Nullable<^T>
-
The input value.
Returns: Nullable<float32>
The converted float32
Modifiers: inline Type parameters: ^T (requires (static member op_Explicit : ^T -> Microsoft.FSharp.Core.float32) and (new : unit -> ^T) and struct and :> System.ValueType) |
Converts the argument to 32-bit float. This is a direct conversion for all primitive numeric types. The operation requires an appropriate static conversion method on the input type.
Example
namespace System
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
Multiple items
type Nullable = static member Compare<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> int static member Equals<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> bool static member GetUnderlyingType: nullableType: Type -> Type static member GetValueRefOrDefaultRef<'T (requires default constructor and value type and 'T :> ValueType)> : nullable: inref<Nullable<'T>> -> inref<'T> <summary>Supports a value type that can be assigned <see langword="null" />. This class cannot be inherited.</summary> -------------------- type Nullable<'T (requires default constructor and value type and 'T :> ValueType)> = new: value: 'T -> unit member Equals: other: obj -> bool member GetHashCode: unit -> int member GetValueOrDefault: unit -> 'T + 1 overload member ToString: unit -> string static member op_Explicit: value: Nullable<'T> -> 'T static member op_Implicit: value: 'T -> Nullable<'T> member HasValue: bool member Value: 'T <summary>Represents a value type that can be assigned <see langword="null" />.</summary> <typeparam name="T">The underlying value type of the <see cref="T:System.Nullable`1" /> generic type.</typeparam> -------------------- Nullable () Nullable(value: 'T) : Nullable<'T> Multiple items
val int: value: 'T -> int (requires member op_Explicit) -------------------- type int = int32 -------------------- type int<'Measure> = int |
|
Converts the argument to signed 32-bit integer. This is a direct conversion for all primitive numeric types. The operation requires an appropriate static conversion method on the input type.
Example
namespace System
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
Multiple items
type Nullable = static member Compare<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> int static member Equals<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> bool static member GetUnderlyingType: nullableType: Type -> Type static member GetValueRefOrDefaultRef<'T (requires default constructor and value type and 'T :> ValueType)> : nullable: inref<Nullable<'T>> -> inref<'T> <summary>Supports a value type that can be assigned <see langword="null" />. This class cannot be inherited.</summary> -------------------- type Nullable<'T (requires default constructor and value type and 'T :> ValueType)> = new: value: 'T -> unit member Equals: other: obj -> bool member GetHashCode: unit -> int member GetValueOrDefault: unit -> 'T + 1 overload member ToString: unit -> string static member op_Explicit: value: Nullable<'T> -> 'T static member op_Implicit: value: 'T -> Nullable<'T> member HasValue: bool member Value: 'T <summary>Represents a value type that can be assigned <see langword="null" />.</summary> <typeparam name="T">The underlying value type of the <see cref="T:System.Nullable`1" /> generic type.</typeparam> -------------------- Nullable () Nullable(value: 'T) : Nullable<'T> Multiple items
val int64: value: 'T -> int64 (requires member op_Explicit) -------------------- type int64 = Int64 -------------------- type int64<'Measure> = int64 |
Full Usage:
Nullable.int16 value
Parameters:
Nullable<^T>
-
The input value.
Returns: Nullable<int16>
The converted int16
Modifiers: inline Type parameters: ^T (requires (static member op_Explicit : ^T -> Microsoft.FSharp.Core.int16) and (new : unit -> ^T) and struct and :> System.ValueType) |
Converts the argument to signed 16-bit integer. This is a direct conversion for all primitive numeric types. The operation requires an appropriate static conversion method on the input type.
Example
namespace System
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
Multiple items
type Nullable = static member Compare<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> int static member Equals<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> bool static member GetUnderlyingType: nullableType: Type -> Type static member GetValueRefOrDefaultRef<'T (requires default constructor and value type and 'T :> ValueType)> : nullable: inref<Nullable<'T>> -> inref<'T> <summary>Supports a value type that can be assigned <see langword="null" />. This class cannot be inherited.</summary> -------------------- type Nullable<'T (requires default constructor and value type and 'T :> ValueType)> = new: value: 'T -> unit member Equals: other: obj -> bool member GetHashCode: unit -> int member GetValueOrDefault: unit -> 'T + 1 overload member ToString: unit -> string static member op_Explicit: value: Nullable<'T> -> 'T static member op_Implicit: value: 'T -> Nullable<'T> member HasValue: bool member Value: 'T <summary>Represents a value type that can be assigned <see langword="null" />.</summary> <typeparam name="T">The underlying value type of the <see cref="T:System.Nullable`1" /> generic type.</typeparam> -------------------- Nullable () Nullable(value: 'T) : Nullable<'T> Multiple items
val int: value: 'T -> int (requires member op_Explicit) -------------------- type int = int32 -------------------- type int<'Measure> = int |
Full Usage:
Nullable.int32 value
Parameters:
Nullable<^T>
-
The input value.
Returns: Nullable<int32>
The converted int32
Modifiers: inline Type parameters: ^T (requires (static member op_Explicit : ^T -> Microsoft.FSharp.Core.int32) and (new : unit -> ^T) and struct and :> System.ValueType) |
Converts the argument to signed 32-bit integer. This is a direct conversion for all primitive numeric types. The operation requires an appropriate static conversion method on the input type.
Example
namespace System
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
Multiple items
type Nullable = static member Compare<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> int static member Equals<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> bool static member GetUnderlyingType: nullableType: Type -> Type static member GetValueRefOrDefaultRef<'T (requires default constructor and value type and 'T :> ValueType)> : nullable: inref<Nullable<'T>> -> inref<'T> <summary>Supports a value type that can be assigned <see langword="null" />. This class cannot be inherited.</summary> -------------------- type Nullable<'T (requires default constructor and value type and 'T :> ValueType)> = new: value: 'T -> unit member Equals: other: obj -> bool member GetHashCode: unit -> int member GetValueOrDefault: unit -> 'T + 1 overload member ToString: unit -> string static member op_Explicit: value: Nullable<'T> -> 'T static member op_Implicit: value: 'T -> Nullable<'T> member HasValue: bool member Value: 'T <summary>Represents a value type that can be assigned <see langword="null" />.</summary> <typeparam name="T">The underlying value type of the <see cref="T:System.Nullable`1" /> generic type.</typeparam> -------------------- Nullable () Nullable(value: 'T) : Nullable<'T> Multiple items
val int64: value: 'T -> int64 (requires member op_Explicit) -------------------- type int64 = Int64 -------------------- type int64<'Measure> = int64 |
Full Usage:
Nullable.int64 value
Parameters:
Nullable<^T>
-
The input value.
Returns: Nullable<int64>
The converted int64
Modifiers: inline Type parameters: ^T (requires (static member op_Explicit : ^T -> Microsoft.FSharp.Core.int64) and (new : unit -> ^T) and struct and :> System.ValueType) |
Converts the argument to signed 64-bit integer. This is a direct conversion for all primitive numeric types. The operation requires an appropriate static conversion method on the input type.
Example
namespace System
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
Multiple items
type Nullable = static member Compare<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> int static member Equals<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> bool static member GetUnderlyingType: nullableType: Type -> Type static member GetValueRefOrDefaultRef<'T (requires default constructor and value type and 'T :> ValueType)> : nullable: inref<Nullable<'T>> -> inref<'T> <summary>Supports a value type that can be assigned <see langword="null" />. This class cannot be inherited.</summary> -------------------- type Nullable<'T (requires default constructor and value type and 'T :> ValueType)> = new: value: 'T -> unit member Equals: other: obj -> bool member GetHashCode: unit -> int member GetValueOrDefault: unit -> 'T + 1 overload member ToString: unit -> string static member op_Explicit: value: Nullable<'T> -> 'T static member op_Implicit: value: 'T -> Nullable<'T> member HasValue: bool member Value: 'T <summary>Represents a value type that can be assigned <see langword="null" />.</summary> <typeparam name="T">The underlying value type of the <see cref="T:System.Nullable`1" /> generic type.</typeparam> -------------------- Nullable () Nullable(value: 'T) : Nullable<'T> Multiple items
val int: value: 'T -> int (requires member op_Explicit) -------------------- type int = int32 -------------------- type int<'Measure> = int |
|
Converts the argument to signed byte. This is a direct conversion for all primitive numeric types. The operation requires an appropriate static conversion method on the input type.
Example
namespace System
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
Multiple items
type Nullable = static member Compare<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> int static member Equals<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> bool static member GetUnderlyingType: nullableType: Type -> Type static member GetValueRefOrDefaultRef<'T (requires default constructor and value type and 'T :> ValueType)> : nullable: inref<Nullable<'T>> -> inref<'T> <summary>Supports a value type that can be assigned <see langword="null" />. This class cannot be inherited.</summary> -------------------- type Nullable<'T (requires default constructor and value type and 'T :> ValueType)> = new: value: 'T -> unit member Equals: other: obj -> bool member GetHashCode: unit -> int member GetValueOrDefault: unit -> 'T + 1 overload member ToString: unit -> string static member op_Explicit: value: Nullable<'T> -> 'T static member op_Implicit: value: 'T -> Nullable<'T> member HasValue: bool member Value: 'T <summary>Represents a value type that can be assigned <see langword="null" />.</summary> <typeparam name="T">The underlying value type of the <see cref="T:System.Nullable`1" /> generic type.</typeparam> -------------------- Nullable () Nullable(value: 'T) : Nullable<'T> Multiple items
val int: value: 'T -> int (requires member op_Explicit) -------------------- type int = int32 -------------------- type int<'Measure> = int |
Full Usage:
Nullable.nativeint value
Parameters:
Nullable<^T>
-
The input value.
Returns: Nullable<nativeint>
The converted nativeint
Modifiers: inline Type parameters: ^T (requires (static member op_Explicit : ^T -> Microsoft.FSharp.Core.nativeint) and (new : unit -> ^T) and struct and :> System.ValueType) |
Converts the argument to signed native integer. This is a direct conversion for all primitive numeric types. Otherwise the operation requires an appropriate static conversion method on the input type.
Example
namespace System
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
Multiple items
type Nullable = static member Compare<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> int static member Equals<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> bool static member GetUnderlyingType: nullableType: Type -> Type static member GetValueRefOrDefaultRef<'T (requires default constructor and value type and 'T :> ValueType)> : nullable: inref<Nullable<'T>> -> inref<'T> <summary>Supports a value type that can be assigned <see langword="null" />. This class cannot be inherited.</summary> -------------------- type Nullable<'T (requires default constructor and value type and 'T :> ValueType)> = new: value: 'T -> unit member Equals: other: obj -> bool member GetHashCode: unit -> int member GetValueOrDefault: unit -> 'T + 1 overload member ToString: unit -> string static member op_Explicit: value: Nullable<'T> -> 'T static member op_Implicit: value: 'T -> Nullable<'T> member HasValue: bool member Value: 'T <summary>Represents a value type that can be assigned <see langword="null" />.</summary> <typeparam name="T">The underlying value type of the <see cref="T:System.Nullable`1" /> generic type.</typeparam> -------------------- Nullable () Nullable(value: 'T) : Nullable<'T> Multiple items
val int: value: 'T -> int (requires member op_Explicit) -------------------- type int = int32 -------------------- type int<'Measure> = int |
Full Usage:
Nullable.sbyte value
Parameters:
Nullable<^T>
-
The input value.
Returns: Nullable<sbyte>
The converted sbyte
Modifiers: inline Type parameters: ^T (requires (static member op_Explicit : ^T -> Microsoft.FSharp.Core.sbyte) and (new : unit -> ^T) and struct and :> System.ValueType) |
Converts the argument to signed byte. This is a direct conversion for all primitive numeric types. The operation requires an appropriate static conversion method on the input type.
Example
namespace System
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
Multiple items
type Nullable = static member Compare<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> int static member Equals<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> bool static member GetUnderlyingType: nullableType: Type -> Type static member GetValueRefOrDefaultRef<'T (requires default constructor and value type and 'T :> ValueType)> : nullable: inref<Nullable<'T>> -> inref<'T> <summary>Supports a value type that can be assigned <see langword="null" />. This class cannot be inherited.</summary> -------------------- type Nullable<'T (requires default constructor and value type and 'T :> ValueType)> = new: value: 'T -> unit member Equals: other: obj -> bool member GetHashCode: unit -> int member GetValueOrDefault: unit -> 'T + 1 overload member ToString: unit -> string static member op_Explicit: value: Nullable<'T> -> 'T static member op_Implicit: value: 'T -> Nullable<'T> member HasValue: bool member Value: 'T <summary>Represents a value type that can be assigned <see langword="null" />.</summary> <typeparam name="T">The underlying value type of the <see cref="T:System.Nullable`1" /> generic type.</typeparam> -------------------- Nullable () Nullable(value: 'T) : Nullable<'T> Multiple items
val int: value: 'T -> int (requires member op_Explicit) -------------------- type int = int32 -------------------- type int<'Measure> = int |
Full Usage:
Nullable.single value
Parameters:
Nullable<^T>
-
The input value.
Returns: Nullable<single>
The converted float32
Modifiers: inline Type parameters: ^T (requires (static member op_Explicit : ^T -> Microsoft.FSharp.Core.single) and (new : unit -> ^T) and struct and :> System.ValueType) |
Converts the argument to 32-bit float. This is a direct conversion for all primitive numeric types. The operation requires an appropriate static conversion method on the input type.
Example
namespace System
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
Multiple items
type Nullable = static member Compare<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> int static member Equals<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> bool static member GetUnderlyingType: nullableType: Type -> Type static member GetValueRefOrDefaultRef<'T (requires default constructor and value type and 'T :> ValueType)> : nullable: inref<Nullable<'T>> -> inref<'T> <summary>Supports a value type that can be assigned <see langword="null" />. This class cannot be inherited.</summary> -------------------- type Nullable<'T (requires default constructor and value type and 'T :> ValueType)> = new: value: 'T -> unit member Equals: other: obj -> bool member GetHashCode: unit -> int member GetValueOrDefault: unit -> 'T + 1 overload member ToString: unit -> string static member op_Explicit: value: Nullable<'T> -> 'T static member op_Implicit: value: 'T -> Nullable<'T> member HasValue: bool member Value: 'T <summary>Represents a value type that can be assigned <see langword="null" />.</summary> <typeparam name="T">The underlying value type of the <see cref="T:System.Nullable`1" /> generic type.</typeparam> -------------------- Nullable () Nullable(value: 'T) : Nullable<'T> Multiple items
val int: value: 'T -> int (requires member op_Explicit) -------------------- type int = int32 -------------------- type int<'Measure> = int |
Full Usage:
Nullable.uint value
Parameters:
Nullable<^T>
-
The input value.
Returns: Nullable<uint>
The converted unsigned integer
Modifiers: inline Type parameters: ^T (requires (static member op_Explicit : ^T -> Microsoft.FSharp.Core.uint) and (new : unit -> ^T) and struct and :> System.ValueType) |
Converts the argument to an unsigned 32-bit integer. This is a direct conversion for all primitive numeric types. The operation requires an appropriate static conversion method on the input type.
Example
namespace System
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
Multiple items
type Nullable = static member Compare<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> int static member Equals<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> bool static member GetUnderlyingType: nullableType: Type -> Type static member GetValueRefOrDefaultRef<'T (requires default constructor and value type and 'T :> ValueType)> : nullable: inref<Nullable<'T>> -> inref<'T> <summary>Supports a value type that can be assigned <see langword="null" />. This class cannot be inherited.</summary> -------------------- type Nullable<'T (requires default constructor and value type and 'T :> ValueType)> = new: value: 'T -> unit member Equals: other: obj -> bool member GetHashCode: unit -> int member GetValueOrDefault: unit -> 'T + 1 overload member ToString: unit -> string static member op_Explicit: value: Nullable<'T> -> 'T static member op_Implicit: value: 'T -> Nullable<'T> member HasValue: bool member Value: 'T <summary>Represents a value type that can be assigned <see langword="null" />.</summary> <typeparam name="T">The underlying value type of the <see cref="T:System.Nullable`1" /> generic type.</typeparam> -------------------- Nullable () Nullable(value: 'T) : Nullable<'T> Multiple items
val int: value: 'T -> int (requires member op_Explicit) -------------------- type int = int32 -------------------- type int<'Measure> = int |
Full Usage:
Nullable.uint16 value
Parameters:
Nullable<^T>
-
The input value.
Returns: Nullable<uint16>
The converted uint16
Modifiers: inline Type parameters: ^T (requires (static member op_Explicit : ^T -> Microsoft.FSharp.Core.uint16) and (new : unit -> ^T) and struct and :> System.ValueType) |
Converts the argument to unsigned 16-bit integer. This is a direct conversion for all primitive numeric types. The operation requires an appropriate static conversion method on the input type.
Example
namespace System
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
Multiple items
type Nullable = static member Compare<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> int static member Equals<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> bool static member GetUnderlyingType: nullableType: Type -> Type static member GetValueRefOrDefaultRef<'T (requires default constructor and value type and 'T :> ValueType)> : nullable: inref<Nullable<'T>> -> inref<'T> <summary>Supports a value type that can be assigned <see langword="null" />. This class cannot be inherited.</summary> -------------------- type Nullable<'T (requires default constructor and value type and 'T :> ValueType)> = new: value: 'T -> unit member Equals: other: obj -> bool member GetHashCode: unit -> int member GetValueOrDefault: unit -> 'T + 1 overload member ToString: unit -> string static member op_Explicit: value: Nullable<'T> -> 'T static member op_Implicit: value: 'T -> Nullable<'T> member HasValue: bool member Value: 'T <summary>Represents a value type that can be assigned <see langword="null" />.</summary> <typeparam name="T">The underlying value type of the <see cref="T:System.Nullable`1" /> generic type.</typeparam> -------------------- Nullable () Nullable(value: 'T) : Nullable<'T> Multiple items
val int: value: 'T -> int (requires member op_Explicit) -------------------- type int = int32 -------------------- type int<'Measure> = int |
Full Usage:
Nullable.uint32 value
Parameters:
Nullable<^T>
-
The input value.
Returns: Nullable<uint32>
The converted uint32
Modifiers: inline Type parameters: ^T (requires (static member op_Explicit : ^T -> Microsoft.FSharp.Core.uint32) and (new : unit -> ^T) and struct and :> System.ValueType) |
Converts the argument to unsigned 32-bit integer. This is a direct conversion for all primitive numeric types. The operation requires an appropriate static conversion method on the input type.
Example
namespace System
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
Multiple items
type Nullable = static member Compare<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> int static member Equals<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> bool static member GetUnderlyingType: nullableType: Type -> Type static member GetValueRefOrDefaultRef<'T (requires default constructor and value type and 'T :> ValueType)> : nullable: inref<Nullable<'T>> -> inref<'T> <summary>Supports a value type that can be assigned <see langword="null" />. This class cannot be inherited.</summary> -------------------- type Nullable<'T (requires default constructor and value type and 'T :> ValueType)> = new: value: 'T -> unit member Equals: other: obj -> bool member GetHashCode: unit -> int member GetValueOrDefault: unit -> 'T + 1 overload member ToString: unit -> string static member op_Explicit: value: Nullable<'T> -> 'T static member op_Implicit: value: 'T -> Nullable<'T> member HasValue: bool member Value: 'T <summary>Represents a value type that can be assigned <see langword="null" />.</summary> <typeparam name="T">The underlying value type of the <see cref="T:System.Nullable`1" /> generic type.</typeparam> -------------------- Nullable () Nullable(value: 'T) : Nullable<'T> Multiple items
val int: value: 'T -> int (requires member op_Explicit) -------------------- type int = int32 -------------------- type int<'Measure> = int |
Full Usage:
Nullable.uint64 value
Parameters:
Nullable<^T>
-
The input value.
Returns: Nullable<uint64>
The converted uint64
Modifiers: inline Type parameters: ^T (requires (static member op_Explicit : ^T -> Microsoft.FSharp.Core.uint64) and (new : unit -> ^T) and struct and :> System.ValueType) |
Converts the argument to unsigned 64-bit integer. This is a direct conversion for all primitive numeric types. The operation requires an appropriate static conversion method on the input type.
Example
namespace System
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
Multiple items
type Nullable = static member Compare<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> int static member Equals<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> bool static member GetUnderlyingType: nullableType: Type -> Type static member GetValueRefOrDefaultRef<'T (requires default constructor and value type and 'T :> ValueType)> : nullable: inref<Nullable<'T>> -> inref<'T> <summary>Supports a value type that can be assigned <see langword="null" />. This class cannot be inherited.</summary> -------------------- type Nullable<'T (requires default constructor and value type and 'T :> ValueType)> = new: value: 'T -> unit member Equals: other: obj -> bool member GetHashCode: unit -> int member GetValueOrDefault: unit -> 'T + 1 overload member ToString: unit -> string static member op_Explicit: value: Nullable<'T> -> 'T static member op_Implicit: value: 'T -> Nullable<'T> member HasValue: bool member Value: 'T <summary>Represents a value type that can be assigned <see langword="null" />.</summary> <typeparam name="T">The underlying value type of the <see cref="T:System.Nullable`1" /> generic type.</typeparam> -------------------- Nullable () Nullable(value: 'T) : Nullable<'T> Multiple items
val int: value: 'T -> int (requires member op_Explicit) -------------------- type int = int32 -------------------- type int<'Measure> = int |
|
Converts the argument to byte. This is a direct conversion for all primitive numeric types. The operation requires an appropriate static conversion method on the input type.
Example
namespace System
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
Multiple items
type Nullable = static member Compare<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> int static member Equals<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> bool static member GetUnderlyingType: nullableType: Type -> Type static member GetValueRefOrDefaultRef<'T (requires default constructor and value type and 'T :> ValueType)> : nullable: inref<Nullable<'T>> -> inref<'T> <summary>Supports a value type that can be assigned <see langword="null" />. This class cannot be inherited.</summary> -------------------- type Nullable<'T (requires default constructor and value type and 'T :> ValueType)> = new: value: 'T -> unit member Equals: other: obj -> bool member GetHashCode: unit -> int member GetValueOrDefault: unit -> 'T + 1 overload member ToString: unit -> string static member op_Explicit: value: Nullable<'T> -> 'T static member op_Implicit: value: 'T -> Nullable<'T> member HasValue: bool member Value: 'T <summary>Represents a value type that can be assigned <see langword="null" />.</summary> <typeparam name="T">The underlying value type of the <see cref="T:System.Nullable`1" /> generic type.</typeparam> -------------------- Nullable () Nullable(value: 'T) : Nullable<'T> Multiple items
val int: value: 'T -> int (requires member op_Explicit) -------------------- type int = int32 -------------------- type int<'Measure> = int |
Full Usage:
Nullable.unativeint value
Parameters:
Nullable<^T>
-
The input value.
Returns: Nullable<unativeint>
The converted unativeint
Modifiers: inline Type parameters: ^T (requires (static member op_Explicit : ^T -> Microsoft.FSharp.Core.unativeint) and (new : unit -> ^T) and struct and :> System.ValueType) |
Converts the argument to unsigned native integer using a direct conversion for all primitive numeric types. Otherwise the operation requires an appropriate static conversion method on the input type.
Example
namespace System
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
Multiple items
type Nullable = static member Compare<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> int static member Equals<'T (requires default constructor and value type and 'T :> ValueType)> : n1: Nullable<'T> * n2: Nullable<'T> -> bool static member GetUnderlyingType: nullableType: Type -> Type static member GetValueRefOrDefaultRef<'T (requires default constructor and value type and 'T :> ValueType)> : nullable: inref<Nullable<'T>> -> inref<'T> <summary>Supports a value type that can be assigned <see langword="null" />. This class cannot be inherited.</summary> -------------------- type Nullable<'T (requires default constructor and value type and 'T :> ValueType)> = new: value: 'T -> unit member Equals: other: obj -> bool member GetHashCode: unit -> int member GetValueOrDefault: unit -> 'T + 1 overload member ToString: unit -> string static member op_Explicit: value: Nullable<'T> -> 'T static member op_Implicit: value: 'T -> Nullable<'T> member HasValue: bool member Value: 'T <summary>Represents a value type that can be assigned <see langword="null" />.</summary> <typeparam name="T">The underlying value type of the <see cref="T:System.Nullable`1" /> generic type.</typeparam> -------------------- Nullable () Nullable(value: 'T) : Nullable<'T> Multiple items
val int: value: 'T -> int (requires member op_Explicit) -------------------- type int = int32 -------------------- type int<'Measure> = int |
FSharp.Core