NullableOperators Module
Operators for working with nullable values, primarily used on F# queries.
Functions and values
| Function or value |
Description
|
Full Usage:
arg0 *? arg1
Parameters:
^T1
arg1 : Nullable<^T2>
Returns: Nullable<^T3>
Modifiers: inline Type parameters: ^T1, ^T2, ^T3 (requires (static member op_Multiply : ^T1 * ^T2 -> ^T3) and (static member op_Multiply : ^T1 * ^T2 -> ^T3) and (new : unit -> ^T2) and struct and :> System.ValueType and (new : unit -> ^T3) and struct and :> System.ValueType) |
|
Full Usage:
arg0 ?* arg1
Parameters:
Nullable<^T1>
arg1 : ^T2
Returns: Nullable<^T3>
Modifiers: inline Type parameters: ^T1, ^T2, ^T3 (requires (static member op_Multiply : ^T1 * ^T2 -> ^T3) and (new : unit -> ^T1) and struct and :> System.ValueType and (static member op_Multiply : ^T1 * ^T2 -> ^T3) and (new : unit -> ^T3) and struct and :> System.ValueType) |
|
Full Usage:
arg0 %? arg1
Parameters:
^T1
arg1 : Nullable<^T2>
Returns: Nullable<^T3>
Modifiers: inline Type parameters: ^T1, ^T2, ^T3 (requires (static member op_Modulus : ^T1 * ^T2 -> ^T3) and (static member op_Modulus : ^T1 * ^T2 -> ^T3) and (new : unit -> ^T2) and struct and :> System.ValueType and (new : unit -> ^T3) and struct and :> System.ValueType) |
|
Full Usage:
arg0 +? arg1
Parameters:
^T1
arg1 : Nullable<^T2>
Returns: Nullable<^T3>
Modifiers: inline Type parameters: ^T1, ^T2, ^T3 (requires (static member op_Addition : ^T1 * ^T2 -> ^T3) and (static member op_Addition : ^T1 * ^T2 -> ^T3) and (new : unit -> ^T2) and struct and :> System.ValueType and (new : unit -> ^T3) and struct and :> System.ValueType) |
|
Full Usage:
arg0 -? arg1
Parameters:
^T1
arg1 : Nullable<^T2>
Returns: Nullable<^T3>
Modifiers: inline Type parameters: ^T1, ^T2, ^T3 (requires (static member op_Subtraction : ^T1 * ^T2 -> ^T3) and (static member op_Subtraction : ^T1 * ^T2 -> ^T3) and (new : unit -> ^T2) and struct and :> System.ValueType and (new : unit -> ^T3) and struct and :> System.ValueType) |
|
Full Usage:
arg0 /? arg1
Parameters:
^T1
arg1 : Nullable<^T2>
Returns: Nullable<^T3>
Modifiers: inline Type parameters: ^T1, ^T2, ^T3 (requires (static member op_Division : ^T1 * ^T2 -> ^T3) and (static member op_Division : ^T1 * ^T2 -> ^T3) and (new : unit -> ^T2) and struct and :> System.ValueType and (new : unit -> ^T3) and struct and :> System.ValueType) |
|
|
|
|
|
|
|
|
|
|
|
|
|
Full Usage:
arg0 ?% arg1
Parameters:
Nullable<^T1>
arg1 : ^T2
Returns: Nullable<^T3>
Modifiers: inline Type parameters: ^T1, ^T2, ^T3 (requires (static member op_Modulus : ^T1 * ^T2 -> ^T3) and (new : unit -> ^T1) and struct and :> System.ValueType and (static member op_Modulus : ^T1 * ^T2 -> ^T3) and (new : unit -> ^T3) and struct and :> System.ValueType) |
|
Full Usage:
arg0 ?%? arg1
Parameters: Returns: Nullable<^T3>
Modifiers: inline Type parameters: ^T1, ^T2, ^T3 (requires (static member op_Modulus : ^T1 * ^T2 -> ^T3) and (new : unit -> ^T1) and struct and :> System.ValueType and (static member op_Modulus : ^T1 * ^T2 -> ^T3) and (new : unit -> ^T2) and struct and :> System.ValueType and (new : unit -> ^T3) and struct and :> System.ValueType) |
|
Full Usage:
arg0 ?*? arg1
Parameters: Returns: Nullable<^T3>
Modifiers: inline Type parameters: ^T1, ^T2, ^T3 (requires (static member op_Multiply : ^T1 * ^T2 -> ^T3) and (new : unit -> ^T1) and struct and :> System.ValueType and (static member op_Multiply : ^T1 * ^T2 -> ^T3) and (new : unit -> ^T2) and struct and :> System.ValueType and (new : unit -> ^T3) and struct and :> System.ValueType) |
|
Full Usage:
arg0 ?+ arg1
Parameters:
Nullable<^T1>
arg1 : ^T2
Returns: Nullable<^T3>
Modifiers: inline Type parameters: ^T1, ^T2, ^T3 (requires (static member op_Addition : ^T1 * ^T2 -> ^T3) and (new : unit -> ^T1) and struct and :> System.ValueType and (static member op_Addition : ^T1 * ^T2 -> ^T3) and (new : unit -> ^T3) and struct and :> System.ValueType) |
|
Full Usage:
arg0 ?+? arg1
Parameters: Returns: Nullable<^T3>
Modifiers: inline Type parameters: ^T1, ^T2, ^T3 (requires (static member op_Addition : ^T1 * ^T2 -> ^T3) and (new : unit -> ^T1) and struct and :> System.ValueType and (static member op_Addition : ^T1 * ^T2 -> ^T3) and (new : unit -> ^T2) and struct and :> System.ValueType and (new : unit -> ^T3) and struct and :> System.ValueType) |
|
Full Usage:
arg0 ?- arg1
Parameters:
Nullable<^T1>
arg1 : ^T2
Returns: Nullable<^T3>
Modifiers: inline Type parameters: ^T1, ^T2, ^T3 (requires (static member op_Subtraction : ^T1 * ^T2 -> ^T3) and (new : unit -> ^T1) and struct and :> System.ValueType and (static member op_Subtraction : ^T1 * ^T2 -> ^T3) and (new : unit -> ^T3) and struct and :> System.ValueType) |
|
Full Usage:
arg0 ?-? arg1
Parameters: Returns: Nullable<^T3>
Modifiers: inline Type parameters: ^T1, ^T2, ^T3 (requires (static member op_Subtraction : ^T1 * ^T2 -> ^T3) and (new : unit -> ^T1) and struct and :> System.ValueType and (static member op_Subtraction : ^T1 * ^T2 -> ^T3) and (new : unit -> ^T2) and struct and :> System.ValueType and (new : unit -> ^T3) and struct and :> System.ValueType) |
|
Full Usage:
arg0 ?/ arg1
Parameters:
Nullable<^T1>
arg1 : ^T2
Returns: Nullable<^T3>
Modifiers: inline Type parameters: ^T1, ^T2, ^T3 (requires (static member op_Division : ^T1 * ^T2 -> ^T3) and (new : unit -> ^T1) and struct and :> System.ValueType and (static member op_Division : ^T1 * ^T2 -> ^T3) and (new : unit -> ^T3) and struct and :> System.ValueType) |
|
Full Usage:
arg0 ?/? arg1
Parameters: Returns: Nullable<^T3>
Modifiers: inline Type parameters: ^T1, ^T2, ^T3 (requires (static member op_Division : ^T1 * ^T2 -> ^T3) and (new : unit -> ^T1) and struct and :> System.ValueType and (static member op_Division : ^T1 * ^T2 -> ^T3) and (new : unit -> ^T2) and struct and :> System.ValueType and (new : unit -> ^T3) and struct and :> System.ValueType) |
|
|
The '<' operator where a nullable value appears on the left This operator is primarily for use in F# queries
Example
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
|
|
The '<=' operator where a nullable value appears on the left This operator is primarily for use in F# queries
Example
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
|
|
|
|
The '<>' operator where a nullable value appears on the left This operator is primarily for use in F# queries
Example
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
|
|
|
|
|
|
The '=' operator where a nullable value appears on the left This operator is primarily for use in F# queries
Example
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
|
|
|
|
The '>' operator where a nullable value appears on the left This operator is primarily for use in F# queries
Example
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
|
|
The '>=' operator where a nullable value appears on the left This operator is primarily for use in F# queries
Example
Multiple items
namespace FSharp -------------------- namespace Microsoft.FSharp namespace Microsoft.FSharp.Linq
module NullableOperators
from Microsoft.FSharp.Linq
|
|
|
|
FSharp.Core