LeafExpressionConverter Module
Contains functionality to convert F# quotations to LINQ expression trees.
Functions and values
| Function or value |
Description
|
|
|
Full Usage:
ImplicitExpressionConversionHelper arg1
Parameters:
'T
Returns: Expression<'T>
Type parameters: 'T |
When used in a quotation, this function indicates a specific conversion should be performed when converting the quotation to a LINQ expression. This function should not be called directly.
|
Full Usage:
MemberInitializationHelper arg1
Parameters:
'T
Returns: 'T
Type parameters: 'T |
When used in a quotation, this function indicates a specific conversion should be performed when converting the quotation to a LINQ expression. This function should not be called directly.
|
Full Usage:
NewAnonymousObjectHelper arg1
Parameters:
'T
Returns: 'T
Type parameters: 'T |
When used in a quotation, this function indicates a specific conversion should be performed when converting the quotation to a LINQ expression. This function should not be called directly.
|
|
Converts a subset of F# quotations to a LINQ expression, for the subset of LINQ expressions represented by the expression syntax in the C# language.
|
Full Usage:
QuotationToLambdaExpression arg1
Parameters:
Expr<'T>
Returns: Expression<'T>
Type parameters: 'T |
Converts a subset of F# quotations to a LINQ expression, for the subset of LINQ expressions represented by the expression syntax in the C# language.
|
FSharp.Core