Lazy<'T> Type
The type of delayed computations.
Use the values in the Lazy module to manipulate
values of this type, and the notation lazy expr to create values
of type Lazy.
The type of delayed computations.
Use the values in the Lazy module to manipulate
values of this type, and the notation lazy expr to create values
of type Lazy.